@@ -6,9 +6,10 @@ use warnings;
 require 5.10.0;
 
 use version;
-our $VERSION = version->declare("v0.2.0");
 
 package code::UnifdefPlus;
+our $VERSION = version->declare("v0.3.0");
+
 use Storable qw(dclone);
 
 my $showErrs=1;
@@ -980,7 +981,7 @@ sub parseIf {
             my ($nextExpression, $wasSimplified) = $self->parseCondition($nextConditional);
 
             #my $nextExpression = $nextConditional;
-            if ( $wasSimplified && $nextExpression =~ m/($WS)$TRUE_PTRN($WS)/ ) {
+            if ( $wasSimplified && $nextExpression =~ /^($WS)$TRUE_PTRN($WS)$/ ) {
                 print $OUTFILE $EXPR->{$lang}->{LIT_ELSE} . "\n" if $self->shouldPrint($keep);
                 ( $nextExprType, $nextConditional ) = $self->parseLines($keep);
                 while ( !( $nextExprType =~ /$EXPR->{$lang}->{ENDIF}/s ) ) {
@@ -992,7 +993,7 @@ sub parseIf {
                     ( $nextExprType, $nextConditional ) = $self->parseLines(0);
                 }
             }
-            elsif ( $wasSimplified && $nextExpression =~ /($WS)$FALSE_PTRN($WS)/ ) {
+            elsif ( $wasSimplified && $nextExpression =~ /^($WS)$FALSE_PTRN($WS)$/ ) {
                 ( $nextExprType, $nextConditional ) = $self->parseLines(0);
             }
             else {
@@ -1016,7 +1017,6 @@ sub parseIf {
 			}
 			if ($elseConditional) {
 				my $rssElseCond;
-				# TBD, clean this up a bit -- do not run if not makefile...
 				($elseConditional, $elseCondition, $rssElseCond) = $self->makefileSimplifyIf($elseConditional, $elseCondition);
 				if ($elseCondition =~ /$TRUE_RESOLVED/) {
 	                print $OUTFILE $EXPR->{$lang}->{LIT_ELSE} . "\n" if $self->shouldPrint($keep);
@@ -1295,6 +1295,7 @@ my %makefileMacroSimplifiers = (
 sub isMakefileExprNonBlank {
 	my $self=shift;
 	my $expr=shift;
+	return 1 if !defined $expr;
 	#tbd:  handle " $$"
 	if ($expr =~ /^(?:\$(?:(?:$PAREN_TOKEN)|(?:\w++)))*([^\$]++)/) {
 		return 1;
@@ -1494,8 +1495,11 @@ sub makefileSimplifyIf()
 	if($ifStmt =~ /^$EXPR->{$lang}->{IFDEF}|^$EXPR->{$lang}->{IFNDEF}/) {
 		#TBD: simplify expression?
 		my $negate = $ifStmt =~ /^$EXPR->{$lang}->{IFNDEF}/;
+		
+		# TBD: we should expand any of the known variables, but for now, just don't simplify...:
+		return ($ifStmt, $condition, RSS_UNCHANGED) if $condition =~ /\$/;
+		
 		my ($var) = $condition =~ /^(\w++)/;
-		die if !$var;
 		if ( $self->{defines}->{$var} ) {
 			$condition = $negate?$FALSE_RESOLVED:$TRUE_RESOLVED;
 			$rss = RSS_RESOLVED;
