@@ -5,15 +5,15 @@ use warnings;
 use FindBin qw($Bin);
 use lib "$Bin/../PerlLib";
 use lib "$Bin/../lib";
+use Carp 'confess';
 use UnifdefPlus;
-use Carp;
 
 require 5.10.0;
 
 # Copyright (C) 2016, John Ulvr
 
-my $version = "0.005.003";
-my $versionString = "0.5.3";
+my $version = "0.005.004";
+my $versionString = "0.5.4";
 
 my $usage = q{
 Usage: 
@@ -173,8 +173,8 @@ while ( my $arg = shift ) {
 if ( ! $language && $inFileName ) 
 {
 	if     ($inFileName =~ /\.*(c|cpp|cc|cxx|h|hpp|hxx)$/i)				{ $language = "C"; }
-	elsif  ($inFileName =~ /^Makfiele|GNUmakefile|(?:.*\.mak$)/i)		{ $language = "Makefile"; }
-	elsif  ($inFileName =~ /^Kconfig.*/i)								{ $language = "Kconfig"; }
+	elsif  ($inFileName =~ /Makefile$|GNUmakefile$|(?:.*\.mak$)/i)		{ $language = "Makefile"; }
+	elsif  ($inFileName =~ /Kconfig[^\\\/]*$/i)							{ $language = "Kconfig"; }
 }
 
 if (($language eq "Makefile") && $isBrcm ) {
